============
Installation
============

At the command line::

    $ pip install lightcurve-fitting

To install the stable version directly from GitHub::

    $ pip install git+https://github.com/griffin-h/lightcurve_fitting.git

If you want the bleeding-edge "development" version (not recommended)::

    $ pip install git+https://github.com/griffin-h/lightcurve_fitting.git@dev

